@@ -19,8 +19,7 @@
 #define ABSTRACTFILELISTING_H
 
 #include "elisaLib_export.h"
-
-#include "notificationitem.h"
+#include "datatypes.h"
 
 #include <QObject>
 #include <QString>
@@ -32,11 +31,8 @@
 #include <memory>
 
 class AbstractFileListingPrivate;
-class MusicAudioTrack;
-class NotificationItem;
 class FileScanner;
 class QFileInfo;
-class QMimeDatabase;
 
 class ELISALIB_EXPORT AbstractFileListing : public QObject
 {
@@ -55,20 +51,16 @@ public:
 
 Q_SIGNALS:
 
-    void tracksList(const QList<MusicAudioTrack> &tracks, const QHash<QString, QUrl> &covers);
+    void tracksList(const DataTypes::ListTrackDataType &tracks, const QHash<QString, QUrl> &covers);
 
     void removedTracksList(const QList<QUrl> &removedTracks);
 
-    void modifyTracksList(const QList<MusicAudioTrack> &modifiedTracks, const QHash<QString, QUrl> &covers);
+    void modifyTracksList(const DataTypes::ListTrackDataType &modifiedTracks, const QHash<QString, QUrl> &covers);
 
     void indexingStarted();
 
     void indexingFinished();
 
-    void newNotification(NotificationItem notification);
-
-    void closeNotification(QString notificationId);
-
     void askRestoredTracks();
 
     void errorWatchingFileSystemChanges();
@@ -79,7 +71,7 @@ public Q_SLOTS:
 
     void init();
 
-    void newTrackFile(const MusicAudioTrack &partialTrack);
+    void newTrackFile(const DataTypes::TrackDataType &partialTrack);
 
     void restoredTracks(QHash<QUrl, QDateTime> allFiles);
 
@@ -101,9 +93,9 @@ protected:
 
     virtual void triggerRefreshOfContent();
 
-    void scanDirectory(QList<MusicAudioTrack> &newFiles, const QUrl &path);
+    void scanDirectory(DataTypes::ListTrackDataType &newFiles, const QUrl &path);
 
-    virtual MusicAudioTrack scanOneFile(const QUrl &scanFile, const QFileInfo &scanFileInfo);
+    virtual DataTypes::TrackDataType scanOneFile(const QUrl &scanFile, const QFileInfo &scanFileInfo);
 
     void watchPath(const QString &pathName);
 
@@ -113,9 +105,9 @@ protected:
 
     void setHandleNewFiles(bool handleThem);
 
-    void emitNewFiles(const QList<MusicAudioTrack> &tracks);
+    void emitNewFiles(const DataTypes::ListTrackDataType &tracks);
 
-    void addCover(const MusicAudioTrack &newTrack);
+    void addCover(const DataTypes::TrackDataType &newTrack);
 
     void removeDirectory(const QUrl &removedDirectory, QList<QUrl> &allRemovedFiles);
 
@@ -133,8 +125,6 @@ protected:
 
     void setWaitEndTrackRemoval(bool wait);
 
-    const QMimeDatabase& mimeDatabase() const;
-
 private:
 
     std::unique_ptr<AbstractFileListingPrivate> d;
