@@ -22,6 +22,8 @@
 
 #include "config-upnp-qt.h"
 
+#include "elisautils.h"
+
 #include <QObject>
 #include <QString>
 
@@ -30,7 +32,6 @@
 class QIcon;
 class QAction;
 class MusicListenersManager;
-class QSortFilterProxyModel;
 class MediaPlayList;
 class AudioWrapper;
 class ManageAudioPlayer;
@@ -43,7 +44,7 @@ class ELISALIB_EXPORT ElisaApplication : public QObject
 
     Q_OBJECT
 
-    Q_PROPERTY(QStringList arguments
+    Q_PROPERTY(ElisaUtils::EntryDataList arguments
                READ arguments
                WRITE setArguments
                NOTIFY argumentsChanged)
@@ -52,42 +53,6 @@ class ELISALIB_EXPORT ElisaApplication : public QObject
                READ musicManager
                NOTIFY musicManagerChanged)
 
-    Q_PROPERTY(QSortFilterProxyModel* allAlbumsProxyModel
-               READ allAlbumsProxyModel
-               NOTIFY allAlbumsProxyModelChanged)
-
-    Q_PROPERTY(QSortFilterProxyModel* allArtistsProxyModel
-               READ allArtistsProxyModel
-               NOTIFY allArtistsProxyModelChanged)
-
-    Q_PROPERTY(QSortFilterProxyModel* allTracksProxyModel
-               READ allTracksProxyModel
-               NOTIFY allTracksProxyModelChanged)
-
-    Q_PROPERTY(QSortFilterProxyModel* allGenresProxyModel
-               READ allGenresProxyModel
-               NOTIFY allGenresProxyModelChanged)
-
-    Q_PROPERTY(QSortFilterProxyModel* allComposersProxyModel
-               READ allComposersProxyModel
-               NOTIFY allComposersProxyModelChanged)
-
-    Q_PROPERTY(QSortFilterProxyModel* allLyricistsProxyModel
-               READ allLyricistsProxyModel
-               NOTIFY allLyricistsProxyModelChanged)
-
-    Q_PROPERTY(QSortFilterProxyModel* singleArtistProxyModel
-               READ singleArtistProxyModel
-               NOTIFY singleArtistProxyModelChanged)
-
-    Q_PROPERTY(QSortFilterProxyModel* singleAlbumProxyModel
-               READ singleAlbumProxyModel
-               NOTIFY singleAlbumProxyModelChanged)
-
-    Q_PROPERTY(QSortFilterProxyModel* fileBrowserProxyModel
-               READ fileBrowserProxyModel
-               NOTIFY fileBrowserProxyModelChanged)
-
     Q_PROPERTY(MediaPlayList *mediaPlayList
                READ mediaPlayList
                NOTIFY mediaPlayListChanged)
@@ -117,28 +82,14 @@ public:
 
     Q_INVOKABLE QString iconName(const QIcon& icon);
 
-    const QStringList &arguments() const;
+    Q_INVOKABLE void installKeyEventFilter(QObject *object);
+
+    bool eventFilter(QObject *object, QEvent *event) override;
+
+    const ElisaUtils::EntryDataList &arguments() const;
 
     MusicListenersManager *musicManager() const;
 
-    QSortFilterProxyModel *allAlbumsProxyModel() const;
-
-    QSortFilterProxyModel *allArtistsProxyModel() const;
-
-    QSortFilterProxyModel *allGenresProxyModel() const;
-
-    QSortFilterProxyModel *allComposersProxyModel() const;
-
-    QSortFilterProxyModel *allLyricistsProxyModel() const;
-
-    QSortFilterProxyModel *allTracksProxyModel() const;
-
-    QSortFilterProxyModel *singleArtistProxyModel() const;
-
-    QSortFilterProxyModel *singleAlbumProxyModel() const;
-
-    QSortFilterProxyModel *fileBrowserProxyModel() const;
-
     MediaPlayList *mediaPlayList() const;
 
     AudioWrapper *audioPlayer() const;
@@ -155,24 +106,6 @@ Q_SIGNALS:
 
     void musicManagerChanged();
 
-    void allAlbumsProxyModelChanged();
-
-    void allArtistsProxyModelChanged();
-
-    void allGenresProxyModelChanged();
-
-    void allComposersProxyModelChanged();
-
-    void allLyricistsProxyModelChanged();
-
-    void allTracksProxyModelChanged();
-
-    void singleArtistProxyModelChanged();
-
-    void singleAlbumProxyModelChanged();
-
-    void fileBrowserProxyModelChanged();
-
     void mediaPlayListChanged();
 
     void audioPlayerChanged();
@@ -183,7 +116,10 @@ Q_SIGNALS:
 
     void manageHeaderBarChanged();
 
-    void enqueue(const QStringList &files);
+    void enqueue(const ElisaUtils::EntryDataList &newEntries,
+                 ElisaUtils::PlayListEntryType databaseIdType,
+                 ElisaUtils::PlayListEnqueueMode enqueueMode,
+                 ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
 
     void initializationDone();
 
@@ -199,7 +135,7 @@ public Q_SLOTS:
 
     void configureElisa();
 
-    void setArguments(const QStringList &newArguments);
+    void setArguments(const ElisaUtils::EntryDataList &newArguments);
 
     void activateActionRequested(const QString &actionName, const QVariant &parameter);
 
@@ -217,6 +153,12 @@ private Q_SLOTS:
 
     void togglePlaylist();
 
+    void seek();
+
+    void scrub();
+
+    void playPause();
+
 private:
 
     void initializeModels();
@@ -225,7 +167,8 @@ private:
 
     void setupActions(const QString &actionName);
 
-    QStringList checkFileListAndMakeAbsolute(const QStringList &filesList, const QString &workingDirectory) const;
+    ElisaUtils::EntryDataList checkFileListAndMakeAbsolute(const ElisaUtils::EntryDataList &filesList,
+                                                              const QString &workingDirectory) const;
 
     std::unique_ptr<ElisaApplicationPrivate> d;
 
