@@ -203,6 +203,8 @@ Q_SIGNALS:
 
     void startedPlayingTrack(const QUrl &fileName, const QDateTime &time);
 
+    void currentPlayingForRadiosChanged(const QVariant &value, int role);
+
 public Q_SLOTS:
 
     void setCurrentTrack(const QPersistentModelIndex &currentTrack);
@@ -237,6 +239,8 @@ public Q_SLOTS:
 
     void setPlayerPosition(qint64 playerPosition);
 
+    void setCurrentPlayingForRadios(QString title, QString nowPlaying);
+
     void setPlayControlPosition(int playerPosition);
 
     void setPersistentState(const QVariantMap &persistentStateValue);
