@@ -79,21 +79,8 @@ bool AbstractMediaProxyModel::sortedAscending() const
 
 void AbstractMediaProxyModel::sortModel(Qt::SortOrder order)
 {
-    this->sort(0,order);
+    this->sort(0, order);
     Q_EMIT sortedAscendingChanged();
 }
 
-void AbstractMediaProxyModel::setGenreFilterText(const QString &filterText)
-{
-    if (mGenreFilterText == filterText)
-    {
-        return;
-    }
-
-    mGenreFilterText = filterText;
-    invalidateFilter();
-
-    Q_EMIT genreFilterTextChanged(mGenreFilterText);
-}
-
 #include "moc_abstractmediaproxymodel.cpp"
