@@ -21,13 +21,13 @@
 #include "elisaLib_export.h"
 
 #include "elisautils.h"
-#include "databaseinterface.h"
+#include "trackslistener.h"
+#include "datatypes.h"
 #include "modeldataloader.h"
 #include "filescanner.h"
 
 #include <QUrl>
 #include <QAbstractListModel>
-#include <QMimeDatabase>
 #include <QFutureWatcher>
 
 class MusicListenersManager;
@@ -44,6 +44,10 @@ class ELISALIB_EXPORT TrackMetadataModel : public QAbstractListModel
                READ fileUrl
                NOTIFY fileUrlChanged)
 
+    Q_PROPERTY(qulonglong databaseId
+               READ databaseId
+               NOTIFY databaseIdChanged)
+
     Q_PROPERTY(MusicListenersManager* manager
                READ manager
                WRITE setManager
@@ -72,7 +76,7 @@ public:
 
     Q_ENUM(ItemType)
 
-    using TrackDataType = DatabaseInterface::TrackDataType;
+    using TrackDataType = DataTypes::TrackDataType;
 
     explicit TrackMetadataModel(QObject *parent = nullptr);
 
@@ -87,7 +91,7 @@ public:
 
     QHash<int, QByteArray> roleNames() const override;
 
-    const QUrl& coverUrl() const;
+    QUrl coverUrl() const;
 
     QString fileUrl() const;
 
@@ -95,11 +99,13 @@ public:
 
     QString lyrics() const;
 
+    qulonglong databaseId() const;
+
 Q_SIGNALS:
 
-    void needDataByDatabaseId(ElisaUtils::PlayListEntryType dataType, qulonglong databaseId);
+    void needDataByDatabaseIdAndUrl(ElisaUtils::PlayListEntryType dataType, qulonglong databaseId, const QUrl &url);
 
-    void needDataByFileName(ElisaUtils::PlayListEntryType dataType, const QUrl &fileName);
+    void needDataByUrl(ElisaUtils::PlayListEntryType dataType, const QUrl &fileName);
 
     void coverUrlChanged();
 
@@ -109,25 +115,42 @@ Q_SIGNALS:
 
     void lyricsChanged();
 
+    void saveRadioData(const DataTypes::TrackDataType &trackDataType);
+
+    void deleteRadioData(qulonglong radioId);
+
+    void databaseIdChanged();
+
 public Q_SLOTS:
 
     void trackData(const TrackMetadataModel::TrackDataType &trackData);
 
-    void initializeByTrackId(qulonglong databaseId);
+    void initializeByIdAndUrl(ElisaUtils::PlayListEntryType type, qulonglong databaseId, const QUrl &url);
 
-    void initializeByTrackFileName(const QUrl &fileName);
+    void initializeByUrl(ElisaUtils::PlayListEntryType type, const QUrl &url);
+
+    void initializeForNewRadio();
 
     void setManager(MusicListenersManager *newManager);
 
     void setDatabase(DatabaseInterface *trackDatabase);
 
+    void saveData();
+
+    void deleteRadio();
+
+    void radioData(const TrackMetadataModel::TrackDataType &radiosData);
+
 protected:
 
-    void fillDataFromTrackData(const TrackMetadataModel::TrackDataType &trackData);
+    void fillDataFromTrackData(const TrackMetadataModel::TrackDataType &trackData,
+                               const QList<DataTypes::ColumnsRoles> &fieldsForTrack);
+
+    void fillDataForNewRadio();
 
     virtual void filterDataFromTrackData();
 
-    void removeMetaData(DatabaseInterface::ColumnsRoles metaData);
+    void removeMetaData(DataTypes::ColumnsRoles metaData);
 
     TrackDataType::mapped_type dataFromType(TrackDataType::key_type metaData) const;
 
@@ -152,6 +175,8 @@ private:
 
     QString mFileUrl;
 
+    qulonglong mDatabaseId = 0;
+
     QList<TrackDataType::key_type> mTrackKeys;
 
     ModelDataLoader mDataLoader;
@@ -160,10 +185,7 @@ private:
 
     FileScanner mFileScanner;
 
-    QMimeDatabase mMimeDatabase;
-
     QFutureWatcher<QString> mLyricsValueWatcher;
-
 };
 
 #endif // TRACKMETADATAMODEL_H
